==> suiviobsmer-ui-0.1.0-sources.jar: fr/ifremer/suiviobsmer/ui/components/Layout.java <==
/*
 * *##% 
 * SuiviObsmer :: Web Interface
 * Copyright (C) 2009 - 2010 Ifremer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * ##%*
 */

package fr.ifremer.suiviobsmer.ui.components;

import fr.ifremer.suiviobsmer.SuiviObsmerBusinessException;
import fr.ifremer.suiviobsmer.SuiviObsmerContext;
import fr.ifremer.suiviobsmer.SuiviObsmerException;
import fr.ifremer.suiviobsmer.entity.User;
import fr.ifremer.suiviobsmer.services.ServiceUser;
import fr.ifremer.suiviobsmer.ui.base.SuiviObsmerPage;
import fr.ifremer.suiviobsmer.ui.pages.Index;
import org.apache.tapestry5.BindingConstants;
import org.apache.tapestry5.annotations.InjectComponent;
import org.apache.tapestry5.annotations.InjectContainer;
import org.apache.tapestry5.annotations.Log;
import org.apache.tapestry5.annotations.Parameter;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.ioc.annotations.Inject;
import org.apache.tapestry5.services.Request;
import org.slf4j.Logger;

/**
 * Layout
 *
 * Created: 9 nov. 2009
 *
 * @author fdesbois
 * @version $Revision: 195 $
 *
 * Mise a jour: $Date: 2010-01-14 15:44:49 +0100 (jeu. 14 janv. 2010) $
 * par : $Author: fdesbois $
 */
public class Layout {

    @Inject
    private Logger log;

    @Parameter(required = true, defaultPrefix = BindingConstants.LITERAL)
    private String pageTitle;

    @Parameter(required = true, defaultPrefix = BindingConstants.LITERAL)
    private String contentId;

    /**
     * Objet de session représentant l'utilisateur identifié
     */
    @SessionState
    private User currentUser;

    /**
     * vrai si l'utilisateur s'est identifié, faux sinon
     */
    @SuppressWarnings("unused")
    @Property
    private boolean currentUserExists;

    @InjectComponent
    private FeedBack connexionFeedback;

    @InjectComponent
    private FeedBack contentFeedback;

    @InjectContainer
    private SuiviObsmerPage page;

    @Inject
    private ServiceUser serviceUser;

    @Inject
    private Request request;

    void setupRender() {
        if(currentUserExists && !canShowPage()) {
            contentFeedback.addError("Vous n'êtes pas autorisé à accéder à cette page !");
        }
    }

    public String getContextPath() {
        return request.getContextPath();
    }

    public String getVersion() {
        return SuiviObsmerContext.getProperty(SuiviObsmerContext.PROP_VERSION);
    }

    /**
     * User for connexion form data
     */
    @Property
    private String login;

    @Property
    private String password;

    @Property
    private String email;

    public String getPageTitle() {
        return this.pageTitle;
    }

    public String getContentId() {
        return this.contentId;
    }
    
    public void setCurrentUser(User user) {
        this.currentUser = user;
    }

    public User getCurrentUser() {
        return this.currentUser;
    }

    public FeedBack getFeedBack() {
        return this.contentFeedback;
    }

    public String getAdminClass() {
        return this.currentUser.getAdmin() ? " admin" : "";
    }

    public String getSamplingSelected() {
        return this.contentId.equals("so-sampling") ? "selected" : "";
    }

    public String getBoatsSelected() {
        return this.contentId.equals("so-boats") ? "selected" : "";
    }

    public String getContactsSelected() {
        return this.contentId.equals("so-contacts") ? "selected" : "";
    }

    public String getSynthesisSelected() {
        return this.contentId.equals("so-synthesis") ? "selected" : "";
    }

    public String getAdminSelected() {
        return this.contentId.equals("so-admin") ? "selected" : "";
    }

    public boolean canShowPage() {
        if (!currentUser.getAdmin()) {
            return !page.isOnlyForAdmin();
        }
        return true;
    }

    @Log
    Object onSuccessFromConnexionForm() throws SuiviObsmerException {
        try {
            currentUser = serviceUser.connect(login, password);
        } catch (SuiviObsmerBusinessException eee) {
            connexionFeedback.addError(eee.getMessage());
        }
        return null;
    }

    public boolean hasConnexionErrors() {
        return connexionFeedback.hasErrors();
    }
    void onSuccessFromForgetPassword() throws SuiviObsmerException {
        try {
            serviceUser.forgetPassword(email);
            connexionFeedback.addInfo("Un email avec votre nouveau mot de passe vous a été envoyé.");
        } catch (SuiviObsmerBusinessException eee) {
            connexionFeedback.addError(eee.getMessage());
        }
    }

    @Log
    Object onActionFromExit() {
         setCurrentUser(null);
         request.getSession(false).invalidate();
         return Index.class;
    }
        
}

==> suiviobsmer-ui-0.2.0-sources.jar: fr/ifremer/suiviobsmer/ui/components/Layout.java <==
/*
 * *##% 
 * SuiviObsmer :: Web Interface
 * Copyright (C) 2009 - 2010 Ifremer
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * ##%*
 */

package fr.ifremer.suiviobsmer.ui.components;

import fr.ifremer.suiviobsmer.SuiviObsmerBusinessException;
import fr.ifremer.suiviobsmer.SuiviObsmerBusinessException.Type;
import fr.ifremer.suiviobsmer.SuiviObsmerContext;
import fr.ifremer.suiviobsmer.SuiviObsmerException;
import fr.ifremer.suiviobsmer.entity.User;
import fr.ifremer.suiviobsmer.services.ServiceUser;
import fr.ifremer.suiviobsmer.ui.base.SuiviObsmerPage;
import fr.ifremer.suiviobsmer.ui.pages.Index;
import org.apache.tapestry5.BindingConstants;
import org.apache.tapestry5.PersistenceConstants;
import org.apache.tapestry5.annotations.InjectComponent;
import org.apache.tapestry5.annotations.InjectContainer;
import org.apache.tapestry5.annotations.Log;
import org.apache.tapestry5.annotations.Parameter;
import org.apache.tapestry5.annotations.Persist;
import org.apache.tapestry5.annotations.Property;
import org.apache.tapestry5.annotations.SessionState;
import org.apache.tapestry5.ioc.annotations.Inject;
import org.apache.tapestry5.services.Request;
import org.slf4j.Logger;

/**
 * Layout
 *
 * Created: 9 nov. 2009
 *
 * @author fdesbois
 * @version $Revision: 248 $
 *
 * Mise a jour: $Date: 2010-01-20 13:00:12 +0100 (mer., 20 janv. 2010) $
 * par : $Author: fdesbois $
 */
public class Layout {

    @Inject
    private Logger log;

    @Parameter(required = true, defaultPrefix = BindingConstants.LITERAL)
    private String pageTitle;

    @Parameter(required = true, defaultPrefix = BindingConstants.LITERAL)
    private String contentId;

    /**
     * Objet de session représentant l'utilisateur identifié
     */
    @SessionState
    private User currentUser;

    /**
     * vrai si l'utilisateur s'est identifié, faux sinon
     */
    @SuppressWarnings("unused")
    @Property
    private boolean currentUserExists;

    @InjectComponent
    private FeedBack connexionFeedback;

    @InjectComponent
    private FeedBack contentFeedback;

    @InjectContainer
    private SuiviObsmerPage page;

    @Inject
    private ServiceUser serviceUser;

    @Inject
    private Request request;

    void setupRender() {
        if(currentUserExists && !canShowPage()) {
            contentFeedback.addError("Vous n'êtes pas autorisé à accéder à cette page !");
        }
    }

    public String getContextPath() {
        return request.getContextPath();
    }

    public String getVersion() {
        return SuiviObsmerContext.getProperty(SuiviObsmerContext.PROP_VERSION);
    }

    /**
     * User for connexion form data
     */
    @Property
    private String login;

    @Property
    private String password;

    @Persist(PersistenceConstants.FLASH)
    @Property
    private String email;

    public String getPageTitle() {
        return this.pageTitle;
    }

    public String getContentId() {
        return this.contentId;
    }
    
    public void setCurrentUser(User user) {
        this.currentUser = user;
    }

    public User getCurrentUser() {
        return this.currentUser;
    }

    public FeedBack getFeedBack() {
        return this.contentFeedback;
    }

    public String getAdminClass() {
        return this.currentUser.getAdmin() ? " admin" : "";
    }

    public String getSamplingSelected() {
        return this.contentId.equals("so-sampling") ? "selected" : "";
    }

    public String getBoatsSelected() {
        return this.contentId.equals("so-boats") ? "selected" : "";
    }

    public String getContactsSelected() {
        return this.contentId.equals("so-contacts") ? "selected" : "";
    }

    public String getSynthesisSelected() {
        return this.contentId.equals("so-synthesis") ? "selected" : "";
    }

    public String getAdminSelected() {
        return this.contentId.equals("so-admin") ? "selected" : "";
    }

    public boolean canShowPage() {
        if (!currentUser.getAdmin()) {
            return !page.isOnlyForAdmin();
        }
        return true;
    }

    @Log
    Object onSuccessFromConnexionForm() throws SuiviObsmerException {
        try {
            // FIXME-FD20100120 Problem with NPE in Topia --> see Ano #243 on nuiton.org
            if (login != null && password != null) {
                currentUser = serviceUser.connect(login, password);
            }
        } catch (SuiviObsmerBusinessException eee) {
            if (eee.getType().equals(Type.BAD_CONNECTION)) {
                connexionFeedback.addError(eee.getMessage());
                email = login;
            } else if (eee.getType().equals(Type.ILLEGAL_CONNECTION)) {
                connexionFeedback.addInfo(eee.getMessage());
            }
        }
        return null;
    }

    public boolean hasConnexionErrors() {
        return connexionFeedback.hasErrors();
    }
    void onSuccessFromForgetPassword() throws SuiviObsmerException {
        try {
            serviceUser.forgetPassword(email);
            connexionFeedback.addInfo("Un email avec votre nouveau mot de passe vous a été envoyé.");
        } catch (SuiviObsmerBusinessException eee) {
            connexionFeedback.addError(eee.getMessage());
        }
    }

    @Log
    Object onActionFromExit() {
         setCurrentUser(null);
         request.getSession(false).invalidate();
         return Index.class;
    }
        
}
